@@ -16,6 +16,7 @@ use Scalar::Util qw/weaken/;
 use Mojo::Base 'Mojolicious';
 use File::HomeDir ();
 use Carp qw( cluck );
+use Clustericious;
 use Clustericious::Controller;
 use Clustericious::Renderer;
 use Clustericious::RouteBuilder::Common;
@@ -23,7 +24,7 @@ use Clustericious::Config;
 use Clustericious::Commands;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 sub _have_rose {
@@ -66,6 +67,13 @@ sub _add_route_builder
 sub startup {
     my $self = shift;
 
+    @{ $self->static->paths } = (
+      Clustericious
+        ->_dist_dir
+        ->subdir(qw( www 1.08 ))
+        ->stringify
+    );
+
     $self->controller_class('Clustericious::Controller');
     $self->renderer(Clustericious::Renderer->new());
     $self->renderer->classes([qw/Clustericious::Templates/]);
@@ -314,7 +322,7 @@ Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
