@@ -10,7 +10,7 @@ use File::Which qw( which );
 use Mojo::URL;
 
 # ABSTRACT: Clustericious command to start plack server
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 __PACKAGE__->attr(description => <<EOT);
@@ -33,7 +33,7 @@ sub run {
   my $url = Mojo::URL->new($self->app->config->url);
   LOGDIE "@{[ $url->scheme ]} not supported" if $url->scheme ne 'http';
   
-  shift @args if $args[0] eq 'plackup';
+  shift @args if defined $args[0] && $args[0] eq 'plackup';
   push @args, $0;
   unshift @args, '--port' => $url->port;
   unshift @args, '--host' => $url->host;
@@ -45,7 +45,6 @@ sub run {
   
   DEBUG "starting $plackup @args";
   delete $ENV{MOJO_COMMANDS_DONE};
-  print "PID = $$\n";
   exec $plackup, @args;
 }
 
@@ -63,7 +62,7 @@ Clustericious::Command::plackup - Clustericious command to start plack server
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
