@@ -6,10 +6,10 @@ use List::Util qw( first );
 use Log::Log4perl qw( :easy );
 use MojoX::Log::Log4perl;
 use File::ReadBackwards;
-use File::HomeDir;
+use Clustericious;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 sub import {
@@ -34,8 +34,7 @@ sub init_logging {
     $Log::Log4perl::Logger::INITIALIZED = 0 if $initPid && $initPid != $$;
     $initPid = $$;
 
-    my $home = File::HomeDir->my_home;
-    my @Confdirs = ($home, "$home/etc", "/etc" );
+    my @Confdirs = Clustericious->_config_path;
 
     # Logging
     $ENV{LOG_LEVEL} ||= 'WARN';
@@ -113,7 +112,7 @@ Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
